@@ -2,11 +2,14 @@
 This plugin searches for Slack tokens
 """
 import re
+from typing import Any
+from typing import cast
+from typing import Dict
 
 import requests
 
-from detect_secrets.core.constants import VerifiedResult
-from detect_secrets.plugins.base import RegexBasedDetector
+from ..constants import VerifiedResult
+from .base import RegexBasedDetector
 
 
 class SlackDetector(RegexBasedDetector):
@@ -23,10 +26,10 @@ class SlackDetector(RegexBasedDetector):
         ),
     )
 
-    def verify(self, token, **kwargs):  # pragma: no cover
-        if token.startswith('https://hooks.slack.com/services/T'):
+    def verify(self, secret: str) -> VerifiedResult:  # pragma: no cover
+        if secret.startswith('https://hooks.slack.com/services/T'):
             response = requests.post(
-                token,
+                secret,
                 json={
                     'text': '',
                 },
@@ -36,10 +39,10 @@ class SlackDetector(RegexBasedDetector):
             response = requests.post(
                 'https://slack.com/api/auth.test',
                 data={
-                    'token': token,
+                    'token': secret,
                 },
             ).json()
-            valid = response['ok']
+            valid = cast(Dict[str, Any], response)['ok']
 
         return (
             VerifiedResult.VERIFIED_TRUE
